@@ -271,7 +271,7 @@ sub draw_items
 					my $iw = $canvas->get_text_width($rref-> [$itemIndex]-> [$umap]);
 					$dx = ($iw < $wx) ? $wx - $iw : 0;
 				}
-				$canvas-> text_out_bidi( $rref-> [$itemIndex]-> [$umap], $x + $txw + $dx, $y);
+				$canvas-> text_shape_out( $rref-> [$itemIndex]-> [$umap], $x + $txw + $dx, $y);
 			}
 		}
 		$xstart += $wx;
@@ -485,7 +485,7 @@ use Prima::DetailedList;
 	$l-> sort(1);
 	run Prima;
 
-=for podview <img src="detailedlist.gif" cut=1>
+=for podview <img src="detailedlist.gif">
 
 =for html <p><img src="https://raw.githubusercontent.com/dk/Prima/master/pod/Prima/detailedlist.gif">
 
