@@ -195,7 +195,7 @@ sub save_dialog
 	my $curr_encoder = 0;
 	my %keys;
 	for ( @{ $codec->{featuresSupported} // [] } ) {
-		next unless m[^encoder\s+(\w+)\s(\w+)[^\(]*\((.*)\)$];
+		next unless m[^encoder\s+(\w+)/(\w+)[^\(]*\((.*)\)$];
 		push @encoders, {
 			compression => $1,
 			text        => "$1/$2",
@@ -253,7 +253,7 @@ sub save_dialog
 		Prima::message($@);
 		return;
 	}
-	$dialog->deepChildLookup(1);
+	$dialog->AUTOLOAD_DEEP_LOOKUP(1);
 	$dialog->Properties->expand_all;
 	$dialog->{refs} = \%data;
 	$dialog->{data} = {};
@@ -284,16 +284,16 @@ sub save_dialog
 
 =head1 NAME
 
-Prima::Image::heif - standard HEIF image save dialog
+Prima::Image::heif
 
 =head1 DESCRIPTION
 
-Provides the standard dialog with save options for HEIF images
+HEIF image save dialog
 
 =head1 INSTALLATION
 
 libheif so far could be built from the sources, and its dependencies as well,
-as major distros do not yet provide the binaries. For Windows, you can grab
+as major distros are not yet providing its binaries. For windows you can grab
 the distro from
 L<http://prima.eu.org/download/libheif-1.12.0-win64.zip>.
 
