@@ -1,12 +1,8 @@
 package Prima::Label;
-use vars qw(@ISA);
-@ISA = qw(Prima::Widget);
-
-use Carp;
-use Prima::Const;
-use Prima::Classes;
 use strict;
 use warnings;
+use Prima;
+use base qw(Prima::Widget);
 
 sub profile_default
 {
