@@ -10,11 +10,9 @@ sub on_mouseup   {}
 package Prima::TextView;
 
 use Prima;
-use Prima::IntUtils;
 use Prima::ScrollBar;
 use Prima::Drawable::TextBlock;
-use vars qw(@ISA);
-@ISA = qw(Prima::Widget Prima::MouseScroller Prima::GroupScroller);
+use base qw(Prima::Widget Prima::Widget::MouseScroller Prima::Widget::GroupScroller);
 
 use constant YMAX => 1000;
 
@@ -93,7 +91,7 @@ sub init
 	$self->{$_} = $profile{$_} for qw(scrollBarClass hScrollBarProfile vScrollBarProfile);
 	for ( qw( autoHScroll autoVScroll colorMap fontPalette
 				hScroll vScroll borderWidth paneWidth paneHeight
-				offset topLine textDirection textRef))
+				offset topLine textDirection text textRef))
 		{ $self-> $_( $profile{ $_}); }
 	return %profile;
 }
@@ -402,7 +400,7 @@ sub block_walk
 
 sub block_wrap
 {
-	my ( $self, $canvas, $b, $state, $width) = @_;
+	my ( $self, $canvas, $b, $state, $width, %opt) = @_;
 	return tb::block_wrap( $b,
 		textPtr       => $self->{text},
 		canvas        => $canvas,
@@ -412,7 +410,21 @@ sub block_wrap
 		baseFontSize  => $self->{defaultFontSize},
 		resolution    => $self->{resolution},
 		wordBreak     => 1,
-		textDirection => $self->{textDirection}, 
+		textDirection => $self->{textDirection},
+		%opt
+	);
+}
+
+sub justify_interspace
+{
+	my ( $self, $canvas, $b, $width) = @_;
+	return tb::justify_interspace( $b,
+		textPtr       => $self->{text},
+		canvas        => $canvas,
+		width         => $width,
+		fontmap       => $self->{fontPalette},
+		baseFontSize  => $self->{defaultFontSize},
+		resolution    => $self->{resolution},
 	);
 }
 
@@ -465,17 +477,22 @@ sub paint_selection
 			for ( my $i = 0; $i < $length; $i++) {
 				if ( $selection_map->[$i] != $self->{selectionPaintMode} ) {
 					if ($vis_end > $vis_start) {
-						my $curr_index = $indexes->[$i];
-						$i++, $vis_end++ while $curr_index == $indexes->[$i + 1];
+						my $curr_index = $indexes->[$i-1];
+						$i++, $vis_end++ while $curr_index == $indexes->[$i];
 						$x += $draw_text->( $glyphs, $x, $vis_start, $vis_end );
 					}
 					$vis_start = $vis_end;
 					$self->{selectionPaintMode} = $selection_map->[$i];
 				}
-				$vis_end++;
+ 				$vis_end++;
 			}
 			$draw_text->( $glyphs, $x, $vis_start, $vis_end )
 				if $vis_end > $vis_start;
+			if ( $sx1 == $offset + $length ) {
+				$self->{selectionPaintMode} = 1;
+			} elsif ( $sx2 == $offset + $length - 1 ) {
+				$self->{selectionPaintMode} = 0;
+			}
 		},
 		code     => sub {
 			my ( $code, $data ) = @_;
@@ -485,6 +502,7 @@ sub paint_selection
 		transpose => sub {
 			my ( $x, $y, $f) = @_;
 			return if !($f & tb::X_EXTEND) || !$self->{selectionPaintMode} || $x == 0 || $y == 0;
+			$self-> realize_state( $canvas, \@state, tb::REALIZE_COLORS);
 			$canvas->clear($xy[0], $xy[1] - $$block[ tb::BLK_APERTURE_Y], $xy[0] + $x - 1, $xy[1] + $y - $$block[ tb::BLK_APERTURE_Y] - 1);
 		},
 	);
@@ -522,9 +540,11 @@ sub on_paint
 
 	my ( $sx1, $sy1, $sx2, $sy2) = @{$self-> {selection}};
 
+	my @visited;
 	for my $ymap_i ( int( $cy[0] / YMAX) .. int( $cy[1] / YMAX)) {
 		next unless $self-> {ymap}-> [$ymap_i];
 		for my $j ( @{$self-> {ymap}-> [$ymap_i]}) {
+			next if $visited[$j]++;
 			$b = $$bx[$j];
 			my ( $x, $y) = (
 				$aa[0] - $offset + $$b[ tb::BLK_X],
@@ -607,7 +627,11 @@ sub xy2info
 		my ( $minxdist, $bdist, $bdistid) = ( $self-> {paneWidth} * 2, undef, undef);
 		for ( @{$self-> {ymap}-> [ $ymapix]}) {
 			my $z = $$bx[$_];
-			if ( $y >= $$z[ tb::BLK_Y] && $y < $$z[ tb::BLK_Y] + $$z[ tb::BLK_HEIGHT]) {
+			if (
+				$y >= $$z[ tb::BLK_Y] &&
+				$y < $$z[ tb::BLK_Y] + $$z[ tb::BLK_HEIGHT] &&
+				$$z[tb::BLK_TEXT_OFFSET] >= 0
+			) {
 				if (
 					$x >= $$z[ tb::BLK_X] &&
 					$x < $$z[ tb::BLK_X] + $$z[ tb::BLK_WIDTH]
@@ -682,6 +706,7 @@ sub xy2info
 	# find text offset
 	my $ofs = 0;
 	my @pos = ($$b[ tb::BLK_X] - $x,0);
+	my $nontext_offset;
 
 	$self-> block_walk( $b,
 		position => \@pos,
@@ -690,7 +715,7 @@ sub xy2info
 			my ( $offset, $length, $width, $text) = @_;
 			my $npx = $pos[0] + $width;
 			if ( $pos[0] > 0) {
-				$ofs = $offset;
+				$ofs = $nontext_offset // $offset;
 				$self-> block_walk_abort;
 			} elsif ( $pos[0] <= 0 && $npx > 0) {
 				my $glyphs = $self-> text_shape( $text );
@@ -704,8 +729,14 @@ sub xy2info
 						($indexes->[$goffs] & ~to::RTL));
 				$self-> block_walk_abort;
 			} else {
-				$ofs = $offset + $length - 1;
+				$ofs = $offset + $length;
 			}
+			undef $nontext_offset;
+		},
+		transpose => sub {
+			my ( $x, $y, $f) = @_;
+			# for cases where a non-text block covers a text range, f ex spaces in justify
+			$nontext_offset = $ofs if $f & tb::X_EXTEND;
 		},
 	);
 
@@ -1070,6 +1101,7 @@ sub selection
 {
 	return @{$_[0]-> {selection}} unless $#_;
 	my ( $self, $sx1, $sy1, $sx2, $sy2) = @_;
+	($sx1, $sy1, $sx2, $sy2) = ( $sx2, $sy2, $sx1, $sy1 ) if $sy1 > $sy2;
 
 	$sy1 = 0 if $sy1 < 0;
 	$sy2 = 0 if $sy2 < 0;
@@ -1089,7 +1121,7 @@ sub selection
 		$y2 = $osy2;
 		if ( $y1 == $y2) {
 			@old = ( $osx1, $osx2 - 1 );
-			@new = (1,0);
+			@new = ();
 		}
 	} else {
 		( $sy1, $sy2, $sx1, $sx2) = ( $sy2, $sy1, $sx2, $sx1) if $sy2 < $sy1;
@@ -1101,7 +1133,7 @@ sub selection
 			$y2 = $sy2;
 			if ( $y1 == $y2) {
 				@new = ( $sx1, $sx2 - 1 );
-				@old = (1,0);
+				@old = ();
 			}
 		} else {
 			if ( $sy1 == $osy1 && $sx1 == $osx1) {
@@ -1116,8 +1148,8 @@ sub selection
 				$y1 = $sy1;
 				$y2 = $osy1;
 				if ( $sy1 == $osy1) {
-					@old = ( $osx1, -1 );
-					@new = ( $sx1,  -1 );
+					@old = ( $osx1, -1);
+					@new = ( $sx1,  -1);
 				}
 			} else {
 				$y1 = ( $sy1 < $osy1) ? $sy1 : $osy1;
@@ -1157,6 +1189,66 @@ sub selection
 		$clipRect[$_+2] = $aa[$_+2] if $clipRect[$_+2] > $aa[$_+2];
 	}
 
+	if ( $y1 == $y2 ) {
+		if ( grep { $_ == -1 } @old, @new ) {
+			my $bx   = $self->{blocks};
+			my $last = (( $y1 < (@{$bx} - 1)) ?
+				$$bx[$y1 + 1]-> [ tb::BLK_TEXT_OFFSET] :
+				length( ${$self-> {text}})
+			) - $$b[ tb::BLK_TEXT_OFFSET];
+			$old[1] = $last if @old && $old[1] == -1;
+			$new[1] = $last if @new && $new[1] == -1;
+		}
+		my @xy = ( $aa[0] - $self->{offset} + $$b[ tb::BLK_X], 0 );
+		my @cr;
+		my $calc = sub {
+			my ( $offset, $glyphs ) = @_;
+			return $offset ? $self->get_text_width($glyphs, 0, 0, $offset) : 0;
+		};
+		$self-> begin_paint_info;
+		my ($last_offset, @nontext);
+
+		$self-> block_walk( $b,
+			trace    => tb::TRACE_GEOMETRY | tb::TRACE_REALIZE_PENS | tb::TRACE_TEXT,
+			canvas   => $self,
+			position => \@xy,
+			text     => sub {
+				my ($offset, $length, undef, $text) = @_;
+				if ( @nontext ) {
+					my ( $s1, $s2 ) = ($last_offset, $offset - 1);
+					my $old_selected = (@old && $s1 >= $old[0] && $s2 <= $old[1]) ? 1 : 0;
+					my $new_selected = (@new && $s1 >= $new[0] && $s2 <= $new[1]) ? 1 : 0;
+					if ( $old_selected != $new_selected ) {
+						$cr[0] //= $nontext[0];
+						$cr[1] = $nontext[2];
+					}
+					undef @nontext;
+				}
+				$last_offset = $offset + $length;
+				my $glyphs  = $self-> text_shape($text);
+				my $oldmap = @old ? $glyphs-> selection_chunks_glyphs( map { $_ - $offset } @old) : [];
+				my $newmap = @new ? $glyphs-> selection_chunks_glyphs( map { $_ - $offset } @new) : [];
+				my $diff   = $glyphs->selection_diff($oldmap, $newmap);
+				return unless @$diff;
+				$cr[0] //= $xy[0] + $calc->($diff->[0], $glyphs);
+				my $end = 0; $end += $_ for @$diff;
+				$cr[1] = $xy[0] + $calc->($end, $glyphs);
+			},
+			transpose => sub {
+				my ( $x, $y, $f ) = @_;
+				return unless $f & tb::X_EXTEND;
+				return unless defined $last_offset;
+				@nontext = (@xy, $xy[0] + $x, $xy[1] + $y);
+			},
+		);
+		$self-> end_paint_info;
+		if ( @cr && $cr[0] != $cr[1] ) {
+			$cr[1]++;
+			$clipRect[0] = $cr[0] if $clipRect[0] < $cr[0];
+			$clipRect[2] = $cr[1] if $clipRect[2] > $cr[1];
+		}
+	}
+
 	push @invalid_rects, \@clipRect;
 
 	my @cpr = $self-> get_invalid_rect;
@@ -1404,6 +1496,9 @@ Also, C<get_selected_text> returns the text within the selection
 the selected text into the clipboard. The latter action is bound to
 C<Ctrl+Insert> key combination.
 
+A block with TEXT_OFFSET set to -1 will be treated as not containing any text,
+and therefore will not be able to get selected.
+
 =head2 Event rectangles
 
 Partly as an option for future development, partly as a hack a
