@@ -1,14 +1,14 @@
 use strict;
 use warnings;
 
-use Prima qw(ScrollWidget);
+use Prima qw(Widget::ScrollWidget);
 # A widget with two scrollbars. Contains set of objects, that know
 # how to draw themselves. The graphic objects hierarchy starts
 # from Prima::CanvasObject:: class
 
 package Prima::Canvas;
 use vars qw(@ISA);
-@ISA = qw(Prima::ScrollWidget);
+@ISA = qw(Prima::Widget::ScrollWidget);
 
 sub profile_default
 {
@@ -69,6 +69,7 @@ sub on_paint
 		);
 		%props = map { $_ => 1 } @uses;
 
+		$canvas-> fillPatternOffset( @r[0,1] );
 		$canvas-> translate( @r[4,5]);
 		$canvas-> clipRect( @r[0..3]);
 		$obj-> on_paint( $canvas, $r[6]-$r[4], $r[7]-$r[5]);
@@ -126,12 +127,7 @@ sub delete_object
 sub insert_object
 {
 	my ( $self, $class) = ( shift, shift);
-	my $obj;
-	$self-> attach_object( $obj = $class-> new(
-		@_,
-		owner => $self,
-	));
-	$obj;
+	return $class-> new( @_, owner => $self );
 }
 
 sub attach_object
@@ -514,8 +510,10 @@ use vars qw(%defaults @uses %list_properties);
 
 {
 	@uses = qw( backColor color fillPattern font lineEnd linePattern
-					lineWidth region rop rop2 textOpaque
-					textOutBaseline lineJoin fillMode);
+		lineWidth region rop rop2 textOpaque
+		textOutBaseline lineJoin fillMode
+		antialias alpha
+	);
 	my $pd = Prima::Drawable-> profile_default();
 	%defaults = map { $_ => $pd-> {$_} } @uses;
 	%list_properties = map { $_ => 1 } qw(origin size rect resolution);
@@ -912,6 +910,20 @@ sub visible
 		if $_[0]-> {owner};
 }
 
+sub alpha
+{
+	return $_[0]-> {alpha} unless $#_;
+	$_[0]-> {alpha} = $_[1];
+	$_[0]-> repaint;
+}
+
+sub antialias
+{
+	return $_[0]-> {antialias} unless $#_;
+	$_[0]-> {antialias} = $_[1];
+	$_[0]-> repaint;
+}
+
 sub color
 {
 	return $_[0]-> {color} unless $#_;
@@ -1010,13 +1022,13 @@ package Prima::Canvas::Outlined;
 use vars qw(@ISA);
 @ISA = qw(Prima::CanvasObject);
 
-sub uses { return qw( rop rop2 backColor color lineWidth linePattern lineEnd); }
+sub uses { return qw( rop rop2 backColor color lineWidth linePattern lineEnd antialias alpha ); }
 
 package Prima::Canvas::Filled;
 use vars qw(@ISA);
 @ISA = qw(Prima::CanvasObject);
 
-sub uses { return qw( rop rop2 color backColor fillPattern lineEnd); }
+sub uses { return qw( rop rop2 color backColor fillPattern lineEnd antialias alpha ); }
 
 package Prima::Canvas::FilledOutlined;
 use vars qw(@ISA);
@@ -1033,7 +1045,7 @@ sub profile_default
 
 sub uses {
 	my $self = $_[0];
-	my @ret = qw(rop rop2 color backColor);
+	my @ret = qw(rop rop2 color backColor antialias alpha);
 	push @ret, qw(lineWidth linePattern lineEnd) if $self-> {outline};
 	push @ret, qw(fillPattern) if $self-> {fill};
 	@ret;
@@ -1574,7 +1586,7 @@ sub profile_default
 sub uses
 {
 	my $self = $_[0];
-	my @ret = qw(font color rop);
+	my @ret = qw(font color rop alpha);
 	push @ret, qw(backColor textOpaque) if $self-> {textOpaque};
 	@ret;
 }
@@ -1737,6 +1749,7 @@ menuItems => [
 	['~Edit' => [
 		['color' => '~Foreground color' => \&set_color],
 		['backColor' => '~Background color' => \&set_color],
+		['alpha' => '~Alpha' => [ map { [ $_, $_, \&set_alpha ] } 0, 32, 64, 96, 128, 164, 192, 224, 255]],
 		[],
 		['~Line width' => [ map { [ "lw$_", $_, \&set_line_width ] } 0..7, 10, 15 ]],
 		['Line ~pattern' => [ map { [ "lp:linePattern=$_", $_, \&set_constant ] }
@@ -1745,15 +1758,39 @@ menuItems => [
 				sort grep { !m/AUTOLOAD|constant|BEGIN|END/ } keys %le:: ]],
 		['Line ~join' => [ map { [ "lj:lineJoin=$_", $_, \&set_constant ] }
 				sort grep { !m/AUTOLOAD|constant|BEGIN|END/ } keys %lj:: ]],
-		['Fill ~pattern' => [ map { [ "fp:fillPattern=$_", $_, \&set_constant ] }
-				sort grep { !m/AUTOLOAD|constant|BEGIN|END/ } keys %fp:: ]],
-		['~Rop' => [ map { [ "rop:rop=$_", $_, \&set_constant ] }
-				sort grep { !m/AUTOLOAD|constant|BEGIN|END/ } keys %rop:: ]],
-		['Rop~2' => [ map { [ "rop:rop2=$_", $_, \&set_constant ] }
-				sort grep { !m/AUTOLOAD|constant|BEGIN|END/ } keys %rop:: ]],
+		['Fill ~pattern' => [
+				[ Icon   => Icon   => \&set_fill_pattern ],
+				[ Bitmap => Bitmap => \&set_fill_pattern ],
+				[],
+				map { [ "fp:fillPattern=$_", $_, \&set_fill_pattern ] }
+					sort grep { !m/AUTOLOAD|constant|BEGIN|END/ } keys %fp::
+		]],
+		['~Rop' => [ map { [ "rop:rop=$_", $_, \&set_constant ] } qw(
+				CopyPut
+				XorPut
+				AndPut
+				OrPut
+				NotPut
+				Invert
+				Blackness
+				NotDestAnd
+				NotDestOr
+				Whiteness
+				NotSrcAnd
+				NotSrcOr
+				NotXor
+				NotAnd
+				NotOr
+				NoOper
+		)]],
+		['Rop~2' => [ map { [ "rop:rop2=$_", $_, \&set_constant ] } qw(
+				CopyPut
+				NoOper
+		)]],
 		['Fill r~ule' => [ map { [ "fm:fillMode=$_", $_, \&set_constant ] }
 				sort grep { !m/AUTOLOAD|constant|BEGIN|END/ } keys %fm:: ]],
 		[],
+		['antialias' => 'Antialia~s' => \&toggle],
 		['fill' => 'Toggle ~fill' => \&toggle],
 		['outline' => 'Toggle ~outline' => \&toggle],
 		[],
@@ -1776,6 +1813,10 @@ menuItems => [
 				map {["arrow=$_", $_, \&set_arrowhead]} 1,2,3,4,5
 			]],
 		]],
+		['Filled shapes' => [
+			['fillBackColor'    => '~Fill back color' => \&set_color],
+			['outlineBackColor' => '~Outline back color' => \&set_color],
+		]],
 		['Te~xt' => [
 			['font' => '~Font' => \&set_font],
 			[],
@@ -1887,11 +1928,20 @@ sub delete
 	$_[0]-> Canvas-> delete_object( $obj);
 }
 
+sub set_alpha
+{
+	my ( $self, $alpha) = @_;
+	my $obj;
+	return unless $obj = $self-> Canvas-> focused_object;
+	$obj-> alpha( $alpha);
+}
+
 sub set_color
 {
 	my ( $self, $property) = @_;
 	my $obj;
 	return unless $obj = $self-> Canvas-> focused_object;
+	return unless $obj->can($property);
 	$colordialog = Prima::Dialog::ColorDialog-> create unless $colordialog;
 	$colordialog-> value( $obj-> $property());
 	$obj-> $property( $colordialog-> value) if $colordialog-> execute != mb::Cancel;
@@ -1907,6 +1957,22 @@ sub set_font
 	$obj-> font( $fontdialog-> logFont) if $fontdialog-> execute != mb::Cancel;
 }
 
+sub set_fill_pattern
+{
+	my ( $self, $fp) = @_;
+	my $obj;
+	return unless $obj = $self-> Canvas-> focused_object;
+
+	if ( $fp eq 'Icon') {
+		$obj-> fillPattern($logo);
+	} elsif ( $fp eq 'Bitmap') {
+		$obj-> fillPattern($bitmap->image);
+	} else {
+		return unless $fp =~ /^(\w+)\:(\w+)\=(.*)$/;
+		$obj-> $2( eval "$1::$3");
+	}
+}
+
 sub set_line_width
 {
 	my ( $self, $lw) = @_;
@@ -2050,8 +2116,8 @@ sub set_text_flags
 }
 
 insert( $c, 'Button', origin => [ 0, 0]);
-insert( $c, 'Rectangle', linePattern => lp::DotDot, lineWidth => 10, origin => [ 50, 50]);
-insert( $c, 'Line', origin => [ 200, 200]);
+insert( $c, 'Rectangle', linePattern => lp::DotDot, lineWidth => 10, origin => [ 50, 50], fillPattern => $logo);
+insert( $c, 'Line', origin => [ 200, 200], antialias => 1);
 insert( $c, 'Polygon', origin => [ 150, 150]);
 insert( $c, 'Bitmap', origin => [ 350, 350], backColor => cl::LightGreen, color => cl::Green);
 
