@@ -1147,7 +1147,7 @@ apc_window_set_icon( Handle self, Handle icon)
 		GC gc;
 		XGCValues gcv;
 
-		and = XCreatePixmap( DISP, guts. root, i-> w, i-> h, 1);
+		and = XCreatePixmap( DISP, guts. root, i-> w, i-> h, guts.depth);
 		if ( !and) {
 			XFreePixmap( DISP, xor);
 			goto FAIL;
@@ -1341,7 +1341,7 @@ apc_window_execute( Handle self, Handle insert_before)
 	protect_object( self);
 
 	XSync( DISP, false);
-	while ( prima_one_loop_round( WAIT_ALWAYS, true) && XX-> flags.modal)
+	while ( prima_one_loop_round( WAIT_IF_NONE, true) && XX-> flags.modal)
 		;
 
 	if ( toplevel) XSetTransientForHint( DISP, X_WINDOW, None);
