@@ -3,7 +3,7 @@ use warnings;
 use Getopt::Long;
 use Prima;
 use Prima::HelpViewer;
-use Prima::Application;
+use Prima::Application name => 'POD viewer';
 
 package SoleHelpViewer;
 use vars qw(@ISA %profile_default);
@@ -94,7 +94,7 @@ podview - graphical pod viewer
 
 =head2 DESCRIPTION
 
-The small GUI browser for POD format. Given the argument either
+A small GUI browser for POD format. Given the argument either
 as a file path, or perl module name (f.ex. I<File::Copy>), displays
 the documentation found.
 
@@ -106,6 +106,10 @@ L<Prima> - perl graphic toolkit the viewer is based on
 
 L<Prima::HelpViewer> - menu commands explained
 
+L<Prima::tutorial/Adding help to your program> - how to add help content
+
 =head1 AUTHORS
 
 Dmitry Karasik E<lt>dmitry@karasik.eu.orgE<gt>
+
+=cut
